@@ -2,21 +2,25 @@
 from unittest import TestCase
 
 import pytest
-from lexicon.tests.providers.integration_tests import IntegrationTests
+
+from lexicon.tests.providers.integration_tests import IntegrationTestsV2
 
 
 # Hook into testing framework by inheriting unittest.TestCase and reuse
 # the tests which *each and every* implementation of the interface must
 # pass, by inheritance from integration_tests.IntegrationTests
-class MemsetProviderTests(TestCase, IntegrationTests):
+class MemsetProviderTests(TestCase, IntegrationTestsV2):
     """TestCase for Memset"""
-    provider_name = 'memset'
-    domain = 'testzone.com'
+
+    provider_name = "memset"
+    domain = "testzone.com"
 
     def _filter_headers(self):
-        return ['Authorization']
+        return ["Authorization"]
 
-    # TODO: the following skipped suite and fixtures should be enabled
+    # TODO: enable the skipped tests
     @pytest.mark.skip(reason="new test, missing recording")
-    def test_provider_when_calling_update_record_should_modify_record_name_specified(self):
+    def test_provider_when_calling_update_record_should_modify_record_name_specified(
+        self,
+    ):
         return
